@@ -1,25 +1,19 @@
 package Email::Store::Date;
-
-use 5.006;
 use strict;
 use warnings;
-
-our $VERSION = '1.1';
-
 use Email::Store::DBI;
 use base 'Email::Store::DBI';
 use Email::Store::Mail;
 
-use Time::Piece;
-use Date::Parse;
+use Email::Date 1.10 ();
 
 Email::Store::Date->table("mail_date");
-Email::Store::Date->columns(All => qw/mail date year month day/);
-Email::Store::Date->columns(Primary => qw/mail/);
+Email::Store::Date->columns( All => qw/mail date year month day/ );
+Email::Store::Date->columns( Primary => qw/mail/ );
 Email::Store::Date->has_a( date => 'Time::Piece' );
 Email::Store::Date->has_a( mail => "Email::Store::Mail" );
-Email::Store::Mail->might_have( mail_date => "Email::Store::Date" => qw(date year month day));
-
+Email::Store::Mail->might_have( mail_date => "Email::Store::Date" =>
+                                  qw(date year month day) );
 
 
 sub on_store_order { 80 }
@@ -28,24 +22,20 @@ sub on_store {
     my ($self, $mail) = @_;
     my $simple = $mail->simple;
 
-    my $date   = $simple->header('date')
-                 || _get_date_in_received_header($simple)
-                 || $simple->header('resent-date');
-
-    my $time   = str2time($date);
-    my $tp     = Time::Piece->new($time);
-    Email::Store::Date->create( { mail => $mail->id, date => $time, year => $tp->year, month => $tp->mon, day => $tp->mday } );
+    my $tp = Email::Date::find_date($simple);
+    
+    # This mirrors old behavior, but seems stupid. -- rjbs, 2006-07-23
+    $tp = Time::Piece->new unless defined $tp;
 
+    Email::Store::Date->create( {
+        mail  => $mail->id,
+        date  => $tp->epoch,
+        year  => $tp->year,
+        month => $tp->mon,
+        day   => $tp->mday,
+    } );
 }
 
-sub _get_date_in_received_header {
-    my @received = shift->header("Received");
-    return unless @received;
-    my $date = $received[-1];
-    $date =~ s/.*;// and return $date;
-}
-
-
 sub on_gather_plucene_fields_order { 80 }
 sub on_gather_plucene_fields {
     my ($self, $mail, $hash) = @_;
@@ -100,7 +90,7 @@ Email::Store::Mail->set_sql(between => qq{
     FROM mail_date, mail
     WHERE mail.message_id = mail_date.mail AND
     mail_date.date >= ? AND
-    mail_date.date <=  ?
+    mail_date.date <= ?
     ORDER BY mail_date.date DESC
 });
 
@@ -108,7 +98,7 @@ Email::Store::Mail->set_sql(between => qq{
 1;
 __DATA__
 CREATE TABLE IF NOT EXISTS mail_date (
-    mail varchar(255) NOT NULL PRIMARY KEY,                                                 
+    mail varchar(255) NOT NULL PRIMARY KEY,
     date  int,
     year  int,
     month int,
